@@ -8,7 +8,7 @@
  * memorandum "A Kernel Model for Precision Timekeeping" by Dave Mills,
  * revised 31 January 1996. That document updates RFC1589.
  *
- * Copyright (c) 1996, 1997 by Ulrich Windl
+ * Copyright (c) 1996, 1997, 1998 by Ulrich Windl
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,7 +24,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: enable_pps.c,v 1.5 1998/02/10 10:55:50 windl Exp $ */
+ * $Id: enable_pps.c,v 1.7 1998/11/30 22:48:15 windl Exp $ */
 #include	<unistd.h>
 #include	<time.h>
 #include	<stdlib.h>
@@ -32,12 +32,23 @@
 #include	<string.h>
 #include	<errno.h>
 #include	<sys/timex.h>
+
 #include	<sys/ppsclock.h>
 #include	<linux/serial.h>
-#include	<sys/ioctl.h>
-#include	<termios.h>
+#if defined(__GNU_LIBRARY__) && __GNU_LIBRARY__ >= 6	/* libc6 or glibc2 */
+# warning	"Compatibility with this library has not been tested a lot!"
+# include	<ioctl-types.h>
+#else
+# include	<sys/ioctl.h>
+				/* conflict: ioctl-types.h vs. some
+				 * linux file
+				 */
+# include	<termios.h>	/* conflict: termbits.h vs. asm/termbits.h
+				 * struct termios differs in size (NCCS)
+				 */
+#endif
 
-static	const char	id[] = "$Id: enable_pps.c,v 1.5 1998/02/10 10:55:50 windl Exp $";
+static	const char	id[] = "$Id: enable_pps.c,v 1.7 1998/11/30 22:48:15 windl Exp $";
 
 static	char	polarity	= 'p';	/* p[ositive] | n[egative] | 0) */
 
